P4 to Git Change 2051060 by michliao@hliao-dev-00-hip.rocm-workspace on 2019/12/30 16:42:07

SWDEV-145570 - Clean up after `hipError_t` unification.

	- Replace deprecated `hipError_t` enums.

Affected files ...

... //depot/stg/opencl/drivers/opencl/api/hip/hip_device_runtime.cpp#24 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_error.cpp#4 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_event.cpp#19 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#94 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_module.cpp#52 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_stream.cpp#27 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_texture.cpp#32 edit
... //depot/stg/opencl/drivers/opencl/api/hip/trace_helper.h#5 edit
This commit is contained in:
foreman
2019-12-30 16:46:39 -05:00
parent 2989140f78
commit 9386736b41
8 changed files with 22 additions and 31 deletions
+3 -3
View File
@@ -183,7 +183,7 @@ hipError_t hipStreamDestroy(hipStream_t stream) {
HIP_INIT_API(hipStreamDestroy, stream);
if (stream == nullptr) {
HIP_RETURN(hipErrorInvalidResourceHandle);
HIP_RETURN(hipErrorInvalidHandle);
}
amd::ScopedLock lock(streamSetLock);
@@ -210,7 +210,7 @@ hipError_t hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int
}
if (event == nullptr) {
HIP_RETURN(hipErrorInvalidResourceHandle);
HIP_RETURN(hipErrorInvalidHandle);
}
hip::Event* e = reinterpret_cast<hip::Event*>(event);
@@ -252,7 +252,7 @@ hipError_t hipStreamAddCallback(hipStream_t stream, hipStreamCallback_t callback
if(!event.setCallback(CL_COMPLETE, ihipStreamCallback, reinterpret_cast<void*>(cbo))) {
command->release();
return hipErrorInvalidResourceHandle;
return hipErrorInvalidHandle;
}
event.notifyCmdQueue();